function r(t,e){if(!t||!e)return"Not available";const n=new Date(t),s=new Date(e);if(isNaN(n.getTime())||isNaN(s.getTime()))return"";const o=Math.abs(s.getTime()-n.getTime()),i=Math.floor(o/(1e3*60)),a=Math.floor(o%(1e3*60)/1e3);return`${i}min ${a}s`}function c(t){const e=new Date,n=new Date;return n.setMonth(e.getMonth()-6),t<n}function u(t){const e=new Date,n=new Date;return n.setFullYear(e.getFullYear()-1),t<n}function f(t){const e=Math.floor(t/3600),n=Math.floor(t%3600/60),s=Math.floor(t%60),o=[];return e>0&&o.push(`${e}h`),n>0&&o.push(`${n}min`),(o.length===0||s>0)&&o.push(`${s}s`),o.join(" ")}export{u as a,r as c,c as i,f as s};
