import{j as o}from"./@radix-3bj3otF9.js";import{S as r}from"./Tabs-B9HamX7S.js";import{R as m}from"./RunsBody-MVRyV0ZL.js";import{R as i}from"./ButtonGroup-C4ao6wx2.js";import{S as p}from"./StackList-DOWge3kz.js";import{a as s}from"./@react-router-Ct_TgVUW.js";import"./index-Cs2FY84s.js";import"./@tanstack-CByuvRcg.js";import"./@reactflow-CwWcBchH.js";import"./chevron-down-smmnLxYI.js";import"./transform-CRpCHU_K.js";import"./KeyValue-Dba6goo4.js";import"./eye-vFb-iYpN.js";import"./CollapsibleCard-ErHP3-9N.js";import"./CodeSnippet-C2p1JJEZ.js";import"./refresh-BaK7e0kN.js";import"./Pagination-Du1A_aqP.js";import"./chevron-right-double-BuLe9bCa.js";import"./SearchField-Bd1JmJXg.js";import"./index-FwZ5fdjO.js";import"./all-pipeline-runs-query-DjqFvEha.js";import"./pipeline-link-W-agDCn-.js";import"./trash-B0fyghWi.js";import"./AlertDialogDropdownItem-WCI5zz6Q.js";import"./DeleteAlertDialog-8-J1PO_I.js";import"./zod-36FJuF1H.js";import"./index.esm-DnoyTjte.js";import"./helper-BXlR2ZLp.js";import"./delete-run-BUeBPA7e.js";import"./bulk-delete-2w7wPalO.js";import"./plus-Cewn_igr.js";import"./index-Aaj1O_4o.js";import"./stack-detail-query-DR_HwbzU.js";import"./SheetHeader-Bv1lWAFV.js";import"./components-Br2ezRib.js";import"./NumberBox-DK1mZUWe.js";import"./ComponentBadge-DxjeE6Hn.js";import"./ComponentIcon-CLH2B8Js.js";import"./bar-chart-square-check-Diki0CFQ.js";import"./layout-zVxDzB0C.js";import"./Infobox-D2Qx_9-M.js";import"./alert-triangle-BvW2I3qT.js";function W(){const{componentId:t}=s();return o.jsx("div",{className:"@container",children:o.jsx(r,{isPanel:!1,stacksTabContent:o.jsx(p,{fixedQueryParams:{component_id:t}}),runsTabContent:o.jsx(i,{children:o.jsx(m,{fixedQueryParams:{stack_component:t}})}),componentId:t})})}export{W as default};
