import{r as e,j as r}from"./@radix-3bj3otF9.js";import{R as m}from"./ButtonGroup-C4ao6wx2.js";import{u as p,g as n,R as u,P as l}from"./service-CaK94xc2.js";import{a as c}from"./@react-router-Ct_TgVUW.js";import"./index-Cs2FY84s.js";import"./@tanstack-CByuvRcg.js";import"./@reactflow-CwWcBchH.js";import"./trash-B0fyghWi.js";import"./AlertDialogDropdownItem-WCI5zz6Q.js";import"./DeleteAlertDialog-8-J1PO_I.js";import"./zod-36FJuF1H.js";import"./index.esm-DnoyTjte.js";import"./helper-BXlR2ZLp.js";import"./delete-run-BUeBPA7e.js";import"./bulk-delete-2w7wPalO.js";import"./refresh-BaK7e0kN.js";import"./SearchField-Bd1JmJXg.js";import"./index-FwZ5fdjO.js";import"./all-pipeline-runs-query-DjqFvEha.js";import"./Pagination-Du1A_aqP.js";import"./chevron-right-double-BuLe9bCa.js";function x(){const s=p(),o=e.useMemo(()=>n().filter(i=>i.id!=="Snapshot"),[]),{snapshotId:a}=c(),t={source_snapshot_id:a,...s};return r.jsxs(r.Fragment,{children:[r.jsx(u,{params:t}),r.jsx(l,{columns:o,params:t})]})}function q(){return r.jsx("div",{className:"space-y-5",children:r.jsx(m,{children:r.jsx(x,{})})})}export{q as default};
